# CubicWeb-Sentry

## Summary

This cube add support of [Sentry](https://sentry.io/) for [CubicWeb](https://www.cubicweb.org/). It is a plug-in for the framework.

## Install it

1. `pip3 install cubicweb-sentry`
2. `add_cube("sentry")`.

## Configure it

See `~/etc/cubicweb.d/<instance-name>/all-in-one.conf`
